import { ItemStack, Player, RawMessage } from "@minecraft/server";
/**
 * Create a QuestBook.
 */
export declare class QuestBook {
    /**
     * The unique id of the QuestBook.
     */
    readonly id: string;
    /**
     * The title the QuestBook.
     */
    title: string | RawMessage;
    body: string | RawMessage;
    private readonly quests;
    constructor(id: string, title: string, body: string | RawMessage, quests: Quest[]);
    display(player: Player): void;
    /**
     * Add a quest.
     * @param quest
     * @param message optional information will be sent to world.
     */
    addQuest(quest: Quest, message?: string | RawMessage): void;
    /**
     * Get the quest by id.
     * @param id
     */
    getQuest(id: string): Quest | undefined;
    /**
     * get all quests.
     */
    getQuests(): Quest[];
}
/**
 * Create a Quest (or Message).
 */
export declare class Quest {
    /**
     * The unique id of the Quest.
     */
    readonly id: string;
    /**
     * The title the Quest.
     */
    protected _title: string | RawMessage;
    /**
     * The content the Quest.
     */
    protected _body: string | RawMessage;
    /**
     * The type the Quest.
     */
    type: QuestTypes;
    /**
     * The condition to complete the quest / unlock the message.
     */
    condition: QuestCondition;
    /**
     * It will be called when the quest is completed by the player.
     */
    award?: QuestAward;
    /**
     * The icon of the Quest.
     * It should be the path from the root of the resource pack.
     * @example texture/gui/example_pic
     */
    icon?: string;
    private readonly form;
    constructor(id: string, title: string | RawMessage, body: string | RawMessage, type: QuestTypes, condition: QuestCondition, award?: QuestAward, icon?: string);
    set body(content: string | RawMessage);
    get body(): string | RawMessage;
    set title(content: string | RawMessage);
    get title(): string | RawMessage;
    /**
     * Return if this quest can be completed.
     * @param player
     */
    canComplete(player: Player): true | RawMessage;
    complete(player: Player): void;
    /**
     * Display the form to a player.
     * @param player
     * @param book if specific, the book will be opened after canceled.
     */
    display(player: Player, book?: QuestBook): void;
    /**
     * Check if a player has completed this quest.
     * @param player
     */
    isCompleted(player: Player): boolean;
    /**
     * Check if the type is INFO
     */
    isMessage(): boolean;
}
/**
 * The type of the quest.
 */
export declare enum QuestTypes {
    INFO = 0,
    QUEST = 1
}
export interface QuestCondition {
    /**
     * Match only typeId and min amount.
     */
    item?: ItemData[];
    /**
     * The specific level will be required to unlock the quest.
     */
    playerXpLevel?: number;
    /**
     * The specific point will be required to unlock the quest.
     */
    playerXpPoint?: number;
    /**
     * Your custom function to check condition.
     * the string (or RawMessage) will be displayed to the player as the quest can not be completed.
     * Return undefined if the quest can be completed.
     */
    custom: (player: Player) => string | RawMessage | undefined;
}
export interface QuestAward {
    /**
     * Player will get these items when the quest is finished.
     */
    item?: ItemData[];
    /**
     * The specific level will be given to the player.
     */
    playerXpLevel?: number;
    /**
     * The specific point will be given to the player.
     */
    playerXpPoint?: number;
    /**
     * Your custom function give award.
     */
    custom: (player: Player) => void;
}
export interface ItemData {
    translateString: string;
    item: ItemStack;
}
